"""
This module has the base layers for the procedural_document models
The layers, on procedural_documents, must inherit from the procedural_documentLayer in order for us to be sure they work
They must have a title, a priority (for the procedural_document.compile() method) and a request.
The ._add method Must be implmented on the specific layer, as they may hava different text lists to extract from
With those base layers we can create the ones that have actual content and can be used in chain to generate modular procedural_documents
"""


class ContentLayer():

    """
    This is our base model, and we treat it as an abstract class
    """
    def __init__(self):
        self.title = None
        self.procedural_document = None
        self.priority = 0
        self.layer_type = None
        self.value = None
        self.dano_moral = 0
        self.request = []

    def _add(self):
        raise NotImplementedError("This is an abstract method")

class Part(ContentLayer):
    """
    The part layer is also an abstract one (as has no ._add)
    its constructor receives name and address, so it can be from both the sued corporation or the author of the petiton
    It also has a parraf attribute, that is where we state the participation of the part on the process
    """
    def __init__(self, name, address):
        super(Part, self).__init__()
        self.layer_type = None
        self.procedural_document = None
        self.name = name
        self.address = address
        self.parraf = []

class Context(ContentLayer):
    """
    Context layers helps us in, on the start of the facts, set a start to the story
    For example, using a context layer we can state that the process happens in the context of a telephone plan
    Here we see that the ._add method sets our facts and has a very high priority.
    """
    def __init__(self):
        super(ContentLayer, self).__init__()
        self.layer_type = "Contexto"
        self.fact = []
        self.priority = 100000
        self.value = None

    def _add(self):
        self.procedural_document.facts.extend(self.fact)
        self.procedural_document.main_req_type = self.pet_type
        self.procedural_document.pet_type = self.pet_type

class Preliminary(ContentLayer):
    """
    The preliminary procedural_documents are used to set some requests on how the process will be judged
    They have also very high priority and a specific list of text for their request.
    They extend the preiliminars and request list of hte procedural_document where it belongs
    """
    def __init__(self):
        super(Preliminary, self).__init__()
        self.layer_type = "Preliminar"
        self.preliminary_request = []
        self.priority = 1000
        self.value = None
    
    def _add(self):
        self.procedural_document.preliminars.extend(self.preliminary_request)
        self.procedural_document.requests.extend(self.request)

class Request(ContentLayer):
    """
    The request layers extend the value of the cause and moral damage from the procedural_document
    They also extend the the_law, requests, facts and docs list from the procedural_document.
    """
    def __init__(self):
        super(Request, self).__init__()
        self.layer_type = "Pedido"
        self.fact = []
        self.law = []
        self.docs = []
        
    def _add(self):
        """
        this method puts all the text that the layers generate for the procedural_document on its right places 
            for later printing and saving
        """
        self.procedural_document.value_of_cause += self.value
        self.procedural_document.dano_moral += self.dano_moral
        self.procedural_document.facts.extend(self.fact)
        self.procedural_document.the_law.extend(self.law)
        self.procedural_document.requests.extend(self.request)
        self.procedural_document.docs.extend(self.docs)





import markdown
import pdfkit
import pypandoc

class ProceduralDocument():

    def __init__(self):
        """
        constructor of the procedural_document type.
        It has lists in order to archive the requests, authors, procedural_document type, legal explanation of the requests and facts that hapenned
        To create it, you pass no parameters.

        You create your procedural_document by instancing procedural_document layers and introducing it with the .add method of the procedural_document
        To organize your text, you use the .compile method, and then can visualize it with .print_text.

        Dano moral is a specific type of request that must be saved as an independent variable due to its importance on the requests

        The attributes are:
        :value of the cause and dano moral: values on which the judgement will be based
        :author -> text list that states the author of the procedural_document
        :counter_part -> text list that states the counter_part of the procedural_document
        :pet_type -> bureaucratic type of the procedural_document (string)
        :perliminars -> text list that states requests about some rules on which the judgement will be based
        :the law -> text list that states the legal explanation of the requests of the procedural_document
        :facts -> text list that states the facts that made the author to ask for his requests
        :requests -> text list that states what the author is actually asking for
        :docs -> the documents that proof that the author is telling the proof (text list)
        """
        self.value_of_cause = 0
        self.dano_moral = 0
        self.pet_type = None
        self.author = []
        self.counter_part = []
        self.preliminars = []
        self.facts = []
        self.the_law = []
        self.requests = []
        self.docs = []

        self.main_req_type = None
        self._request_obj_list = []
        self.compiled = False
        self.file_name = None
        pass

    def summary(self):
        """
        Returns none, prints to the screen
        As this lib is inspired in keras, our procedural_document model object has a summary function
        It gives us an ordered list of the procedural_document titles and the final value of the cause
        """
        assert self.compiled == True, "Precisa compilar a peticao"
        
        print("{}".format(self.pet_type))
        print("#############")
        print("CAMADAS DA PETICAO:")
        for i in self._request_obj_list:
            print("{}".format(i.layer_type))
        print("#############")
        print("Valor da causa: R$ {}".format(self.value_of_cause))

    def add(self, layer):
        """

        With this method, you add a layer to the procedural_document model
        Returns none and sets the procedural_document of the layer to be the one where it is being added
        It is important in order to add the requests to value of the cause and interact with other layers on the same pet_model
        """
        layer.procedural_document = self
        self._request_obj_list.append(layer)
        pass

    def compile(self):

        """
        This is one of the most important methods of the core procedural_document model
        It compiles the procedural_document by organizing its texts
        It sorts the request_obj_list to the correct order (by putting the parts and preliminaries first)
        Then calls each layer on the list method ._add to introduce its text blocks on the correct list of the procedural_document

        It also, it has alleged moral damage, creates an specific request to it.
        It also crates a request with the value of the cause, which is important on Brazilian law-processes
        """
        self._request_obj_list.sort(key= lambda i: -1 * i.priority)
        for request in self._request_obj_list:
            request._add()
        self.compiled = True
        if self.dano_moral:
            base = "A condenacao da parte re ao pagamento de um total de R$ {} a titulo de danos morais, em virtude do exposto"
            base = base.format(self.dano_moral)
            self.requests.append(base)
        t1 = "Da-se a causa o valor de R$ {}".format(self.value_of_cause)
        self.requests.append(t1)
        pass
    
    def print_text(self):

        """
        This method prints the procedural_document text on the screen and indexes each parraf
        """
        idx = 1
        print("### **EXMO SR JUIZ DE DIREITO DO JEC DO TJSP**", end="\n\n\n\n")
        for text in self.author:
            print(text)
        print("**" + self.main_req_type.upper()+ "**" + "\n\n")
        for text in self.counter_part:
            print(text, end="\n\n")
        if len(self.preliminars) > 0:
            print("#### **PRELIMINARES**")
            for text in self.preliminars:
                print("**" + str(idx) + "."+ "** " + text, end="\n\n")
                idx += 1
        print("\n#### **DOS FATOS**")
        for text in self.facts:
            print("**" + str(idx) + "."+ "** " + text, end="\n\n")
            idx += 1
        print("\n#### **DO DIREITO**")
        for text in self.the_law:
            print("**" + str(idx) + "."+ "** " + text, end="\n\n")
            idx += 1
        print("\n#### **DOS PEDIDOS**")
        p = 1
        for text in self.requests:
            print("**" + str(p) + "."+ "** " + text, end="\n\n")
            p += 1
        print("\nTermos em que pede deferimento")
        print(self.author_name)

    def _get_text(self):

        """
        Gets the whole procedural_document as a very big string
        """
        idx = 1
        as_txt = ''
        as_txt = as_txt + ("### **EXCELENTÍSSIMO SENHOR DOUTOR JUIZ DE DIREITO DO JUIZADO ESPECIAL CÍVEL DO TRIBUNAL DE JUSTIÇA DO ESTADO DE SÃO PAULO**" + "<br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/>\n\n")
        for text in self.author:
            as_txt = as_txt + text + "\n\n"
        as_txt = as_txt + "<br/>**" + self.main_req_type.upper()+ "**<br/><br/>" + "\n\n"
        for text in self.counter_part:
            as_txt = as_txt + text + "\n\n<br/><br/><br/><br/>"
        if len(self.preliminars) > 0:
            as_txt = as_txt + ("\n\n<br/><br/>\n#### **PRELIMINARES**\n\n")
            for text in self.preliminars:
                as_txt = as_txt + "\n\n<br/>" + ("**" + str(idx) + "."+ "** " + text + "\n\n")
                idx += 1
        as_txt = as_txt + ("\n\n<br/><br/>\n#### **DOS FATOS**\n\n")
        for text in self.facts:
            as_txt = as_txt + "\n\n<br/>" + ("**" + str(idx) + "."+ "** " + text + "\n\n")
            idx += 1
        as_txt = as_txt + ("\n\n<br/><br/>\n#### **DO DIREITO**\n\n")
        for text in self.the_law:
            as_txt = as_txt + "\n\n<br/>" + ("**" + str(idx) + "."+ "** " + text + "\n\n")
            idx += 1
        as_txt = as_txt + "\n\n<br/><br/>\n#### **DOS PEDIDOS**\n\n"
        p = 1
        for text in self.requests:
            as_txt = as_txt + "\n\n<br/>" + ("**" + str(p) + "."+ "** " + text + "\n\n")
            p += 1
        as_txt = as_txt + ("\n<br/><br/>Termos em que pede deferimento\n\n")
        as_txt = as_txt + self.author_name
        as_txt = as_txt + "\n\n" + '<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css" integrity="sha384-Vkoo8x4CGsO3+Hhxv8T/Q5PaXtkKtu6ug5TOeNV6gBiFeWPGFN9MuhOf23Q9Ifjh" crossorigin="anonymous">'
        #as_txt = as_txt + '<script src="https://code.jquery.com/jquery-3.4.1.slim.min.js" integrity="sha384-J6qa4849blE2+poT4WnyKhv5vZF5SrPo0iEjwBvKU7imGFAV0wwj1yYfoRSJoZ+n" crossorigin="anonymous"></script>\
         #   <script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.0/dist/umd/popper.min.js" integrity="sha384-Q6E9RHvbIyZFJoft+2mJbHaEWldlvI9IOYy5n3zV9zzTtmI3UksdQRVvoxMfooAo" crossorigin="anonymous"></script>\
          #  <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/js/bootstrap.min.js" integrity="sha384-wfSDF2E50Y2D1uUdj0O3uMBJnjuUD4Ih7YwaYd1iqfktj0Uod8GCExl3Og8ifwB6" crossorigin="anonymous"></script>'
        return as_txt

    def _save_as_html(self, path):
        "Saves as .html file centralized, uses bootstrap"
        txt = self._get_text() 
        self.file_name = path
        html = markdown.markdown(txt)
        html = '<div class=container style="font-size:25px">' + html + '</div<'
        html = '<div class="text-justify">\n' + html + '</div>'
        html = '<main class="bd-masthead" id="content" role="main">' + html + '</main>'
        html = '<head><meta charset="utf-8"></head>' + html
        with open(path+'.html', "w") as file:
            file.write(html)
    
    def _save_as_pdf(self):
        "gathers converts the html saved file to pdf"
        assert self.file_name is not None, "The html must be generated first"
        pdfkit.from_file(self.file_name+'.html', self.file_name+'.pdf')

    def _save_as_docx(self):
        output = pypandoc.convert(source=self.file_name+'.html',
                          format='html',
                          to='docx',
                          outputfile=self.file_name+'.docx')

    def save_document(self, path, to_pdf=True, to_word=False):
        self._save_as_html(path)
        if to_pdf:
            self._save_as_pdf()
        if to_word:
            self._save_as_docx()





from setuptools import setup, find_packages
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_desc = f.read()

setup(
    name = "slingshot-lawdocs",
    packages = find_packages(),
    version = "0.5.4",
    license = "MIT",
    description = "Slingshot is a Python library bringed on by A Mosca team for creating reproducible procedural documents for Brazilian law-suits.",
    author = "A Mosca",
    author_email = "staff.amosca@gmail.com",
    url = "https://github.com/amosca-team/slingshot/",
    long_description = long_desc,
    long_description_content_type='text/markdown',
    install_requires = ["pdfkit",
                        "pypandoc",
                        "markdown"
                        ],
    classifiers = [
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.7"
    ]
)


"""
On this module we show some example implementations of the petition layers implementation
With these layers, you can create a petition to sue a Telecom corporation for some damage they brought you

As you may see on the next examples, all we have to do is, using the classes of the lib, create reusable
content blocks that can set its parts to the correspondent part of the document (facts, law, requests)
"""


from .base import *

class ContratoServicos(Context):
    def __init__(self, service, docs):
        super(ContratoServicos, self).__init__()
        self.layer_type = "Contexto - Prestação de serviços"
        self.pet_type = "Ação condenatória com base no CDC"
        self.service = service
        self.docs = docs
        self.priority = 10000000
        self.set_text()
        
    def set_text(self):
        self.set_fact()
        
    def set_fact(self):
        docs = str(self.docs).replace("[", "").replace("]", "")
        base = "Conforme a documentação anexa ({}) parte autora firmou com a parte requerida " \
        "contrato de prestação de serviços, mais especificamente por meio de {}. Ocorre que, durante " \
        "a execução do contrato, a parte ré teve uma série de condutas que passaram a prejudicar a autora."
        base = base.format(docs, self.service)
        t1 = "Ainda conforme a documentação, a parte autora tentou de todos os meios amigáveis possiveis" \
        "para a solução dos problemas que seguem, tornando esta ação a unica solução possível."
        self.fact.append(base)
        self.fact.append(t1)

class InversaoOnusProva(Preliminary):
    def __init__(self):
        super(InversaoOnusProva, self).__init__()
        self.layer_type = "Preliminar - Inversao ônus da prova"
        self.set_text()
    
    def set_text(self):
        self.set_request()
        self.set_preliminary()
    
    def set_preliminary(self):
        base = "Em virtude da nitida situacao de hipossuficiente da parte autora, " \
        "e do art 6o, inciso VIII do CDC e, faz-se necessaria" \
        "inversão do ônus da prova em favor da parte autora neste processo."
        base = base + "\n" \
        + """\n\n* *Art. 6°. São direitos básicos do consumidor:* \n* *(...) VIII – a facilitação da defesa de seus direitos, inclusive com a inversão do ônus da prova, a seu favor, no processo civil, quando, a critério do juiz, for verossímil a alegação ou quando for ele hipossuficiente, segundo as regras ordinárias de experiências (...).*"""


        self.preliminary_request.append(base)
        
    def set_request(self):
        base = "Seja deferida a inversão do onus da prova em favor da parte autora."
        self.request.append(base)

class CobrancaIndevida(Request):
    def __init__(self, tarifas_cobradas, valor, docs, conta_paga=False):
        super(CobrancaIndevida, self).__init__()
        self.layer_type = "Cobranca indevida"
        self.valor_cobrado = valor
        self.value = 2 * valor
        self.tarifas = tarifas_cobradas
        self.conta_paga = conta_paga
        self.docs = docs

        self.set_texts()
    
    def set_texts(self):
        self.set_facts()
        self.set_law()
        self.set_requests()
    
    def set_facts(self):
        docs = str(self.docs).replace("[", "").replace("]", "")
        tarifas = str(self.tarifas).replace("[", "").replace("]", "")
        base = "Conforme a documentacao anexa {}, a parte re cobrou indevidamente " \
        "da autora valores que perfazezm o montate de R$ {}, sob a invalida justificativa " \
        " de corresponderem a {}".format(docs, self.valor_cobrado, tarifas)
        if self.conta_paga:
            base = base + ", cobrando inclusive valores que já foram pagos, como provam os anexos."
        else:
            base = base + "."
        t1 = "A parte autora ressalta que jamais anuiu com a cobranca indevida desses valores, seja como prestacao de servicos adicionais" \
        ", reajuste no plano ou qualquer outro tipo de cobranca, de maneira que resta ilicita e incorreta a referida cobranca de valores."
        self.fact.append(base)
        self.fact.append(t1)
        
    def set_law(self):
        base = "De acordo com o Art 42, Parágrafo Único, do CDC, quando houver cobranca indevida, o consumidor tem direito " \
        "a repeticao do indebito em dobro (*Parágrafo único. O consumidor cobrado em quantia indevida tem direito à repetição do indébito, por valor igual ao dobro do que pagou em excesso, acrescido de correção monetária e juros legais, salvo hipótese de engano justificável.*)"
        t1 = "O mesmo ainda é encontra base na jurisprudência, que reconhece, inclusive, a exitência de dano moral em caso de cobrança indevida - inclusive por causa da ocorrência de desvio produtivo do consumidor:" \
            "\n\n * PRESTAÇÃO DE SERVIÇOS INEXISTENTE - COBRANÇA INDEVIDA - RESTITUIÇÃO EM DOBRO E COMPENSAÇÃO" \
            "POR DANO MORAL – RECONHECIMENTO – FIXAÇÃO EM R$ 7.000,00 - PRETENSÃO DA AUTORA EM" \
            "MAJORAÇÃO – IMPERTINÊNCIA - RECURSO NÃO PROVIDO. - *Tribunal de Justiça de São Paulo TJ-SP - Apelação Cível : AC" \
            "1000854-52.2018.8.26.0161*"
        self.law.append(base)
        self.law.append(t1)
        
    def set_requests(self):
        base = "A repetição do indébito em dobro, de acordo com o exposto e no valor de R$ {}."
        base = base.format(str(self.value))
        self.request.append(base)

class ImpossivelCancelar(Request):
    def __init__(self, dano_moral, docs=False):
        super(ImpossivelCancelar, self).__init__()
        self.layer_type = "Impossivel cancelar plano"
        self.value = dano_moral
        self.dano_moral += dano_moral
        self.docs = docs
        self.set_texts()
    
    def set_texts(self):
        self.set_facts()
        self.set_law()
        self.set_requests()
    
    def set_facts(self):
        base = "Ocorre que a parte autora vem tentando, sem sucesso, cancelar seu plano e, depois " \
        "de varias tentativas, não conseguiu ter sucesso. Isso se deu por conduta ativa e dolosa " \
        "da parte ré que, desnecessariamente demora excessivamente e dificulta toda forma de comunicação" \
        "no que diz respeito ao cancelamento do plano."
        t1 = "Vale dizer que a parte ré sempre mostrou prontidao quando do momento da contratação, mas " \
        "quando se quis proceder o cancelamento, passou a agir com essa conduta desrespeitosa que causou " \
        "grande desconforto e sentimento de humilhação, traduzido em dano moral, para a parte autora."
        self.fact.append(base)
        self.fact.append(t1)
        if self.docs:
            docs = str(self.docs).replace("[", "").replace("]", "")
            t2 = "Isso encontra respaldo documental na documentacao anexa ({})".format(docs)
            self.fact.append(t2)
        
    def set_law(self):
        base = "Ademais do dano moral, cuja necessidade de ressarcimento tem resguardo legislativo" \
        "no Codigo Civil art 186, 188 e 187, o mesmo, para esse tipo de caso do consumidor, encontra respaldo no" \
        "art 14, caput do CDC (*Art. 14. O fornecedor de serviços responde, independentemente da existência de culpa, pela reparação dos danos causados aos consumidores por defeitos relativos à prestação dos serviços, bem como por informações insuficientes ou inadequadas sobre sua fruição e riscos.*)"
        t1 = "Existe ainda respaldo jurisprudencial no sentido de entender a gravidade e a necessidade de " \
        "ressarcimento deste tipo de dano, inclusive por causa do desvio produtivo do consumidor, como ja foi reconhecido pelo STJ:"\
        """\n\n* PROCESSO CIVIL E DIREITO DO CONSUMIDOR. RECURSO ESPECIAL. AÇÃO CIVIL PÚBLICA. NEGATIVA DE PRESTAÇÃO JURISDICIONAL. AUSÊNCIA. JUNTADA DE DOCUMENTOS COM A APELAÇÃO. POSSIBILIDADE. VÍCIO DO PRODUTO. REPARAÇÃO EM 30 DIAS. RESPONSABILIDADE OBJETIVA DO COMERCIANTE.1. Ação civil pública ajuizada em 07/01/2013, de que foi extraído o presente recurso especial, interposto em 08/06/2015 e concluso ao Gabinete em 25/08/2016. Julgamento pelo CPC/73.2. Cinge-se a controvérsia a decidir sobre: (i) a negativa de prestação jurisdicional (art. 535, II, do CPC/73); (ii) a preclusão operada quanto à produção de prova (arts. 462 e 517 do CPC/73); (iii) a responsabilidade do comerciante no que tange à disponibilização e prestação de serviço de assistência técnica (art. 18, caput e § 1º, do CDC).3. Devidamente analisadas e discutidas as questões de mérito, e fundamentado o acórdão recorrido, de modo a esgotar a prestação jurisdicional, não há que se falar em violação do art. 535, II, do CPC/73.4. Esta Corte admite a juntada de documentos, que não apenas os produzidos após a inicial e a contestação, inclusive na via recursal, desde que observado o contraditório e ausente a má-fé. **5. À frustração do consumidor de adquirir o bem com vício, não é razoável que se acrescente o desgaste para tentar resolver o problema ao qual ele não deu causa, o que, por certo, pode ser evitado – ou, ao menos, atenuado – se o próprio comerciante participar ativamente do processo de reparo, intermediando a relação entre consumidor e fabricante, inclusive porque, juntamente com este, tem o dever legal de garantir a adequação do produto oferecido ao consumo. 6. À luz do princípio da boa-fé objetiva, se a inserção no mercado do produto com vício traz em si, inevitavelmente, um gasto adicional para a cadeia de consumo, esse gasto deve ser tido como ínsito ao risco da atividade, e não pode, em nenhuma hipótese, ser suportado pelo consumidor. Incidência dos princípios que regem a política nacional das relações de consumo, em especial o da vulnerabilidade do consumidor (art. 4º, I, do CDC) e o da garantia de adequação, a cargo do fornecedor (art. 4º, V, do CDC), e observância do direito do consumidor de receber a efetiva reparação de danos patrimoniais sofridos por ele (art. 6º, VI, do CDC).** 7. Como a defesa do consumidor foi erigida a princípio geral da atividade econômica pelo art. 170, V, da Constituição Federal, é ele – consumidor – quem deve escolher a alternativa que lhe parece menos onerosa ou embaraçosa para exercer seu direito de ter sanado o vício em 30 dias – levar o produto ao comerciante, à assistência técnica ou diretamente ao fabricante –, não cabendo ao fornecedor impor-lhe a opção que mais convém. 8. Recurso especial desprovido. *RESP - 1634851, Rel. Min. Nancy Andrighi*"""
        self.law.append(base)
        self.law.append(t1)
        
    def set_requests(self):
        base = "O cancelamento imediato de todos os serviços que a parte ré se recusou a cancelar ou dificultou o cancelamento."
        self.request.append(base)

class RegistroSerasa(Request):
    def __init__(self, divida_registrada, valor, docs):
        super(RegistroSerasa, self).__init__()
        self.layer_type = "Registro indevido no Serasa"
        self.value = valor
        self.suposta_divida = divida_registrada
        self.docs = docs
        self.set_texts()
    
    def set_texts(self):
        self.set_facts()
        self.set_law()
        self.set_requests()
    
    def set_facts(self):
        docs = str(self.docs).replace("[", "").replace("]", "")
        base = "Conforme a documentação anexa ({}), a parte re registrou divida inexistente " \
        "da autora no valor o montate de R$ {}, nas empresas de score de crédito, a título de {}. " \
        "Ocorre que as referidas supostas dívidas nao existem e não justificam o cadastro nos bancos de score de crédito.".format(docs, self.value, self.suposta_divida)
        t1 = "A parte autora ainda ressalta não ser devedor contumaz, de forma que o registro indevido " \
        "do nome nas empresas de score de credito caracteriza dano moral."
        self.fact.append(base)
        self.fact.append(t1)
        
    def set_law(self):
        base = "De acordo com o Art 42, caput do CDC/CC, o consumidor não será exposto a ridículo quando da cobrança de dívidas. (*Art. 42. Na cobrança de débitos, o consumidor inadimplente não será exposto a ridículo, nem será submetido a qualquer tipo de constrangimento ou ameaça.*)"
        t1 = "Ocorre que, neste caso, isso aconteceu, tendo em vista que a inserção de seu nome indevidamente no cadastro de devedores " \
        "o expõe ao ridículo e abala a sua imagem, além de impedir que adquira crédito no mercado. Por isso, deve haver remoção imediata de seu nome dos respectivos cadastros "\
        "e compensacao pelo dano moral e à sua imagem. "
        t2 = "Esse entendimento foi validado em jurisprudencia, que, inclusive, reconhece a existência de dano moral "\
            "para esse tipo de caso de inclusão indevida no cadastro de devedores do Serasa:\n\n"\
            """ * PRESTAÇÃO DE SERVIÇOS DE TELEFONIA AÇÃO DE CANCELAMENTO DE COBRANÇA INDEVIDA E DE REGISTRO INDEVIDO JUNTO AO SERASA/SPCC/C REPARAÇÃO DE DANOS MORAIS COM PEDIDO DE TUTELA ANTECIPADA INEXIGIBILIDADE DOS DÉBITOS SERVIÇO CONTRATADO FUNCIONAMENTO NÃO COMPROVADO PESSOA JURÍDICA NEGATIVAÇÃO INDEVIDA DO NOME DA AUTORA EM ÓRGÃOS DE PROTEÇÃO AO CRÉDITO DANO MORALCARACTERIZADO SENTENÇA QUE ARBITROU QUANTIA EM CONFORMIDADE COMOS CRITÉRIOS DE PROPORCIONALIDADE E RAZOABILIDADE INDENIZAÇÃO DEVIDA FIXADA EM R$ 10.000,00 VALOR MANTIDO SENTENÇA MANTIDA. *TJSP- Apelação cível AC :  0058685-32.2012.8.26.0114 publicado em 24/01/2017*"""
        self.law.append(base)
        self.law.append(t1)
        self.law.append(t2)
        
    def set_requests(self):
        base = "A imediata retirada da anotacao nas empresas de Score de credito da alegada divida " \
        "indevidamente cobrada pela parte re"
        base.format(str(self.value * 2))
        self.request.append(base)

class PropagandaEnganosa(Request):
    def __init__(self, prometido, real, valor, docs, dano_ocorrido=None, deseja_prometido=False):
        super(PropagandaEnganosa, self).__init__()
        self.layer_type = "Propaganda enganosa"
        self.value = 1000
        self.prometido = prometido
        self.dano_ocorrido = dano_ocorrido
        self.real = real
        self.deseja_prometido = deseja_prometido
        self.docs = docs
        self.set_texts()

    def set_texts(self):
        self.set_facts()
        self.set_law()
        self.set_requests()
    
    def set_facts(self):
        base = "No contexto da relação jurídica entre as partes, conforme provam os documentos anexos ({}), a parte autora realizou negócio com a ré"\
            "acreditando se tratar que, a prestação que lhe cabia era '{}', que foi o comunicado pela ré na oferta."\
            " Ocorre que, na realidade, o que lhe foi prestado foi {}, nítidamente diferente do prometido."
        base = base.format(self.docs, self.prometido, self.real)
        t1 = "Esse feito, como é de senso comum caracteriza propaganda enganosa, dada a divergência entre o prometido "\
            "e o prestado pela ré. Além do sentimento de humilhação e dano à sua moral, a parte autora teve prejuízo "\
                "em razão do que lhe fora prometido e não concedido."
        if self.dano_ocorrido is not None:
            t1 = t1 + " Mais especificamente, teve planejado '{}' e não pode realizar por conta da má conduta da parte ré."
            t1 = t1.format(self.dano_ocorrido)
        self.fact.append(base)
        self.fact.append(t1)

    def set_law(self):
        base = "Da definição de propaganda enganosa, do CDC, Art. 37, parágrafo primeiro *§ 1° É enganosa qualquer modalidade de informação ou comunicação de caráter publicitário, inteira ou parcialmente falsa, ou, por qualquer outro modo, mesmo por omissão, capaz de induzir em erro o consumidor a respeito da natureza, características,"\
            "qualidade, quantidade, propriedades, origem, preço e quaisquer outros dados sobre produtos e serviços.* Fica nítido que é esse o caso ocorrido."
        t1 = "A jurisprudência já se manifesta no sentido de reconhecer a abusividade da propaganda enganosa e o ensejo que dá à indenização: "\
            "\n\n* AÇÃO DE INDENIZAÇÃO POR DANOS MORAIS – Propaganda enganosa – Autora que foi levada à loja do Carrefour no intuito de aderir à promoção que, na compra de uma Margarina Delícia Supreme de 500g, levava outra de 250g por R$0,01 – PROCEDÊNCIA, condenando o réu ao pagamento de indenização por danos morais de R$ 8.800,00 – Propaganda enganosa caracterizada – Dano moral existente, que decorre da violação das garantias consumeristas e do fato de a consumidora ter se sentido lesada e enganada – Indenização devida – SENTENÇA MANTIDA – NEGADO PROVIMENTO AO RECURSO."\
                " - APL 1014687-61.2015.8.26.0576, 12a Camara de Direito Privado, Julgado em 22/09/2017, Relator: Ramon Mateo Júnior"
        self.law.append(base)
        self.law.append(t1)

    def set_requests(self):
        base = "Seja reconhecido o dano moral proveniente da propaganda enganosa da parte ré"
        self.request.append(base)
        if self.deseja_prometido:
            t1 = "Seja a ré condenada a realizar conforme prometido na sua conduta de propaganda enganosa"
            self.request.append(t1)
        
class DanoMoral(Request):
    def __init__(self, dano_moral):
        self.priority = -1
        super(DanoMoral, self).__init__()
        self.value = dano_moral
        self.dano_moral += dano_moral
        self.layer_type = "Dano moral puro"


from slingshot.procedural_document.layers.models import ContratoServicos, InversaoOnusProva, PropagandaEnganosa
from slingshot.procedural_document.layers.models import CobrancaIndevida, ImpossivelCancelar, DanoMoral, RegistroSerasa
from slingshot.procedural_document.layers.parts import *
from slingshot.procedural_document.core import ProceduralDocument

pet = ProceduralDocument()

pet.add(Author(name="A Mosca",
               profession="nerds bravos com computadores",
               address="Rua da Nossa Casinha, casa 1000",
               cpf="123.456.789-00"))

pet.add(ContratoServicos(service="adesão a plano de celular",
                        docs = ["contas pagas"]))

pet.add(Claro_SP_re)

pet.add(InversaoOnusProva())

pet.add(PropagandaEnganosa(prometido="plano de internet sem corte de dados",
                          real="plano de celular com corte de dados ao fim da franquia",
                          valor=1000,
                          docs="fotos e panfletos da operadora",
                          dano_ocorrido="usar o GPS na volta do trabalho, para não se atrasar para buscar o amigo",
                          deseja_prometido=True))

pet.add(CobrancaIndevida(tarifas_cobradas=["Dados a mais"],
                         valor=2000,
                         docs=["contas"]))

pet.add(RegistroSerasa(divida_registrada="Conta do celular (11) - 99999-8888",
                       valor=2000,
                        docs=["Conta do mês de setembro"]))

pet.add(ImpossivelCancelar(dano_moral=3000,
                           docs=["Pedido de cancelamento e email"]))

pet.add(DanoMoral(2000))

pet.compile()
pet.summary()
a = pet.save_document('yee')


from .base import *

class Author(Part):

    """
    This layer introduces the author of the procedural_document and creates the text where it states the who the author is
    On Brazil, the author must have a CPF (SSN-like), profession, address and name.
    We inherit from the Part layer and introduce some more attributes and methods.

    The create parraf create th author declaring statement 
    The _add method introduces them on the right places of the procedural_document
    """
    def __init__(self, name, address, cpf, profession):
        super(Author, self).__init__(name, address)
        self.layer_type = "Autor"
        self.CPF = cpf
        self.profession = profession
        self.priority = 1000000000
        self.create_parraf()
    
    def create_parraf(self):
        base = "{}, {}, domiciliado em {}, sob o CPF {} vem diante da Vossa Exa. ajuizar"
        base = base.format(self.name, self.profession, self.address, self.CPF)
        self.parraf.append(base)


    def _add(self):
        self.procedural_document.author.extend(self.parraf)
        self.procedural_document.author_name = self.name

class CounterPart(Part):
    """
    This layer introduces the counterpart of the procedural_document and creates the text where it states the who the counterpart is
    On Brazil, the author must have a CNPJ (register number-like), profession, address and name.
    We inherit from the Part layer and introduce some more attributes and methods.

    The create parraf create the counterpart declaring statement 
    The _add method introduces them on the right places of the procedural_document
    """
    
    def __init__(self, name, address, cnpj):
        super(CounterPart, self).__init__(name, address)
        self.layer_type = "Parte Re"
        self.CNPJ = cnpj
        self.priority = 1000000000 - 1
        self.create_parraf()
    
    def create_parraf(self):
        base = """Em face de {}, com sede em {}, sob o CNPJ {}, pelas razoes de fato e Direito aqui expostas:"""
        base = base.format(self.name, self.address, self.CNPJ)
        self.parraf.append(base)

    def _add(self):
        self.procedural_document.counter_part.extend(self.parraf)


#AS MAIS IMPORTANTES TELES
#SE VC VAI COMEÇAR A AUTOMATIZAR PROCESSO, CERTAMENTE VAI PASSAR POR AQUI

TIM_SP_re = CounterPart(name = "TIM Celular S/A",
                     cnpj = "04.206.050/0001-80",
                     address = "Av Giovanni Gronchi, 7143, São Paulo - SP, CEP: 05724-003")

Claro_SP_re = CounterPart(name = "Claro S/A",
                     cnpj = "40.432.544/0001-47",
                     address = "Rua Henri Durant, 780, Santo Amaro, Sao Paulo - SP, CEP: 04709-110")

Vivo_SP_re = CounterPart(name = "Telefonica Brasil S/A (Vivo)",
                     cnpj = "02.558.157/0001-62",
                     address = "Av. Engenheiro Luiz Carlos Berrini, 1376, São Paulo -SP, CEP: 04571-936")

Oi_SP_re = CounterPart(name = "Oi Móvel S/A – em recuperação judicial",
                     cnpj = "05.423.963/0026-70",
                     address = "Rua Arquiteto Olavo Redig de Campos, 105 Torre A - 15º andar - Chácara Santo Antônio, São Paulo / SP - CEP: 04711-904")

Nextel_SP_re = CounterPart(name = "NEXTEL TELECOMUNICAÇÕES S/A",
                     cnpj = "66.970.229/0001-67",
                     address = "Avenida das Nações Unidas, nº 14.171, 32º andar - Condomínio Rochaverá Corporate Towers - Crystal TowerVila Gertrudes, São Paulo -SP, CEP 04794-000")                